#!/bin/bash
# TESTFSAP - a shell script (version 16 Mar 2023)
# Run FSAP programs on test datasets.
# 
# 'testfsap.sh' with no arguments tests all FSAP programs.
# 'testfsap.sh program_name' tests the one program
# eg. 'testfsap.sh numseq' tests numseq

#####################################################################
# set default parameters
#####################################################################

# RM_CMD - command to be used for removing files and directories
if [ -e /usr/bin/rm ]
then
   RM_CMD=/usr/bin/rm
else
   if [ -e /bin/rm ]
   then
      RM_CMD=/bin/rm
   else
      RM_CMD=rm
   fi
fi
BINDIR=../bin-$BIRCH_PLATFORM

# set $testset to programs to be tested.
NUMARGS=$#

if [[ $NUMARGS == 0 ]]
then 
   TESTSET="bachrest d3hom d4hom funnel multidigest gel numseq\
       giganumseq p1hom p2hom testcode"
else
   TESTSET=$1
fi

#####################################################################
# test programs one at a time
#####################################################################
for PROGRAM in $TESTSET
do
  echo "Testing $PROGRAM ..."
  # remove previous output, if any, and then run the program
  if [ -f temp.$PROGRAM.out ]
  then
     $RM_CMD -f temp.$PROGRAM.out
  fi
  $BINDIR/$PROGRAM <$PROGRAM.inp

  # if successful, compare sample files with new output
  SUCCESS=$?
  if [[ $SUCCESS == 0 ]]
  then
     echo "     $PROGRAM successful"
     echo "     Comparing sample files with new output (temp.*)..."
     diff $PROGRAM.out temp.$PROGRAM.out > result
     if  [ ! -s result ] 
     then
        echo "     output files compare okay"
        $RM_CMD -f temp.$PROGRAM.out result
     else
        echo ">>>> $PROGRAM.out is different from temp.$PROGRAM.out"
        echo ">>>> see difference.$PROGRAM"
        mv result difference.$PROGRAM
     fi 
   else
     echo ">>>> $PROGRAM failed"
  fi
done #foreach

echo TEST OF FSAP COMPLETE
